embassy-stm32

Crates

git

Versions

stm32f101zd

Flavors

TIM4

Struct TIM4 

pub struct TIM4 { /* private fields */ }
TIM4 peripheral

Implementations

Source

impl TIM4

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.